@@ -1,6 +1,6 @@
 import requests
 import json
-from pyups.typings import PICKUP_TYPES, CANCEL_BY
+from pyups.typings import PICKUP_TYPES, CANCEL_BY, UPSHeader
 
 from typing import Dict, Optional
 
