@@ -1,10 +1,16 @@
 import json
 import requests
+from pyups.typings import UPSHeader
 from typing import Dict
 
 
 class Shipping:
-    def __init__(self, header):
+    """UPS Shipping API"""
+
+    __slots__ = ["_base_url", "_header"]
+
+    def __init__(self, base_url: str, header: UPSHeader):
+        self._base_url = base_url
         self._header = header
 
     def request(
@@ -13,7 +19,7 @@ class Shipping:
         aav: str = "city",
     ) -> object:
         response: requests.Response = requests.post(
-            url=f"https://onlinetools.ups.com/ship/V1801/shipments?additionaladdressvalidation={aav}",
+            url=f"{self._base_url}/ship/V1801/shipments?additionaladdressvalidation={aav}",
             headers=self._header,
             data=json.dumps(data),
         )
@@ -21,7 +27,7 @@ class Shipping:
 
     def label(self, data: Dict[str, any]) -> object:
         response: requests.Response = requests.post(
-            url=f"https://onlinetools.ups.com/ship/V1903/shipments/labels",
+            url=f"{self._base_url}/ship/V1903/shipments/labels",
             headers=self._header,
             data=json.dumps(data),
         )
@@ -30,7 +36,7 @@ class Shipping:
     def void(self, shipment_identification_number: str) -> object:
         # todo add tracking number support
         response: requests.Response = requests.post(
-            url=f"https://onlinetools.ups.com/ship/v1/shipments/cancel/{shipment_identification_number.upper()}",
+            url=f"{self._base_url}/ship/v1/shipments/cancel/{shipment_identification_number.upper()}",
             headers=self._header,
             data=json.dumps(data),
         )
